PyXMake Developer Guide: src/PyXMake/VTL/stm_post.py Source File

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
stm_post.py
1# -*- coding: utf-8 -*-
2# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
3# % PyXMake - Build environment for PyXMake %
4# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
5"""
6Jenkins2 post-processing script.
7
8@note: Post-processing build jobs on Jenkins2 using PyXMake.
9
10@version: 1.0
11----------------------------------------------------------------------------------------------
12@requires:
13 - PyXMake, PyCODAC
14
15@change:
16 -
17
18@author:
19 - garb_ma [DLR-FA,STM Braunschweig]
20----------------------------------------------------------------------------------------------
21"""
22
23## @package PyXMake.VTL.stm_post
24# Post-processing build jobs on Jenkins2 using PyXMake.
25## @author
26# Marc Garbade
27## @date
28# 03.04.2021
29## @par Notes/Changes
30# - Added documentation // mg 03.04.2021
31
32import os, sys
33
34try:
35 import PyXMake as _ #@UnusedImport
36except ImportError:
37 # Script is executed as a plug-in
38 sys.path.insert(0,os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
39 if "PyCODAC" in os.path.abspath(__file__): sys.path.insert(0,os.path.join(str(os.path.abspath(__file__)).split("PyCODAC")[0],"PyCODAC","Plugin"))
40finally:
41 from PyXMake.Tools import Utility #@UnresolvedImport
42
43 def main():
44 """
45 Main function to execute the script.
46 """
47 # Start
48 print("==================================")
49 print("Attempting to kill unattended processes...")
50 print("==================================")
51
52 Utility.ProcessWalk(os.getenv('stm_process',''))
53
54 # Finish
55 print("==================================")
56 print("Finished")
57 print("==================================")
58
59if __name__ == "__main__":
60 main(); sys.exit(0)
PyXMake.Tools
Module containing basic functionalities defined for convenience.
Definition __init__.py:1
PyXMake.VTL.stm_post.main
main()
Definition stm_post.py:43